@@ -20,7 +20,7 @@ except ImportError:
 from bitmaptools import draw_line
 from vectorio import Rectangle
 
-__version__ = "0.7.0"
+__version__ = "0.8.0"
 __repo__ = "https://github.com/adafruit/CircuitPython_uplot.git"
 
 # pylint: disable=too-many-arguments, invalid-name, protected-access
@@ -48,7 +48,7 @@ class ubar:
         self._new_max = int(plot.transform(0, max(y), max(y), 0, max(y)))
 
         bar_space = max(2, plot._width // 30)
-        xstart = self._graphx + bar_space
+        xstart = self._graphx + plot._newxmin
 
         plot._plot_palette[plot._index_colorused] = color
 
